summaryrefslogtreecommitdiff
path: root/ui/gtk/tap_param_dlg.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2013-05-24 01:10:16 +0000
committerGuy Harris <guy@alum.mit.edu>2013-05-24 01:10:16 +0000
commit699f06760cae98892f7b728c84d7eb341d454b9e (patch)
tree78574d48547e74e41f99de3a847af41aba3cf0ef /ui/gtk/tap_param_dlg.h
parent3c41347f677b371bcae3ad70259b878ee3c44f51 (diff)
downloadwireshark-699f06760cae98892f7b728c84d7eb341d454b9e.tar.gz
A long-overdue rename of register_dfilter_stat() to
register_param_stat() to reflect that it's for arbitrary statistics tap parameters, not just a display filter. svn path=/trunk/; revision=49549
Diffstat (limited to 'ui/gtk/tap_param_dlg.h')
-rw-r--r--ui/gtk/tap_param_dlg.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/ui/gtk/tap_param_dlg.h b/ui/gtk/tap_param_dlg.h
index 9c3aa93ee3..9ed9f06ef8 100644
--- a/ui/gtk/tap_param_dlg.h
+++ b/ui/gtk/tap_param_dlg.h
@@ -39,9 +39,9 @@
* on the start button in the display filter dialog.
* 4) the index with "-1"
*
- * Within register_tap_menu_yourtap(void), call register_dfilter_stat()
+ * Within register_tap_menu_yourtap(void), call register_param_stat()
* with a pointer to the tap_param_dlg structure, a string for the
* menu item (don't put "..." at the end, register_dfilter_stat() will
* add it for you), and the REGISTER_STAT_GROUP_ value for the stat
* group to which your stat should belong.
*
@@ -55,7 +55,7 @@
* };
*
* register_tap_menu_mytap(void) {
- * register_dfilter_stat(&my_tap_param_dlg, "My Menu Item",
+ * register_param_stat(&my_tap_param_dlg, "My Menu Item",
* REGISTER_STAT_GROUP_my_group);
* }
*
@@ -88,10 +88,10 @@ typedef struct _tap_param_dlg {
} tap_param_dlg;
/*
- * Register a stat that has a display filter dialog.
+ * Register a stat that has a parameter dialog.
* We register it both as a command-line stat and a menu item stat.
*/
-void register_dfilter_stat(tap_param_dlg *info, const char *name,
+void register_param_stat(tap_param_dlg *info, const char *name,
register_stat_group_t group);
void tap_param_dlg_cb(GtkAction *action, gpointer user_data);
@@ -39,9 +39,9 @@
* with a pointer to the tap_param_dlg structure, a string for the
- * menu item (don't put "..." at the end, register_dfilter_stat() will
+ * menu item (don't put "..." at the end, register_param_stat() will
* add it for you), and the REGISTER_STAT_GROUP_ value for the stat
* group to which your stat should belong.